pub struct ChocoBackend { /* private fields */ }Implementations
Sourceimpl ChocoBackend
impl ChocoBackend
Sourcepub fn set_dll_folder(dll_folder_path: String) -> Result<(), Option<String>>
pub fn set_dll_folder(dll_folder_path: String) -> Result<(), Option<String>>
Sets the folder path where the DLL files are located.
Arguments
dll_folder_path- AStringrepresenting the path to the folder containing the DLL files.
Example
use choco_solver::ChocoBackend;
ChocoBackend::set_dll_folder(String::from("C:/path/to/dll/folder"));Note
This function should be called before any interaction with the Choco backend,
as it configures the directory from which the libchoco_capi library will be loaded.
If not set, the library will be searched in folder specified by environment variable CHOCO_SOLVER_DLL_FOLDER.
If the environment variable is not set, the library will be searched in the default system paths.