pub struct Solution { /* private fields */ }Expand description
A solver result holding instantiated variable values.
Implementations
Sourceimpl Solution
impl Solution
Sourcepub fn get_int_var(&self, int_var: &IntVar<'_>) -> Option<i32>
pub fn get_int_var(&self, int_var: &IntVar<'_>) -> Option<i32>
Gets the value of an integer variable in this solution. :TODO: presently if the var is not instantiated in solution Java raise an exception Need to be added a new function in backend to check if the var is instantiated
Sourcepub fn get_bool_var(&self, bool_var: &BoolVar<'_>) -> Option<bool>
pub fn get_bool_var(&self, bool_var: &BoolVar<'_>) -> Option<bool>
Gets the value of a boolean variable in this solution. :TODO: presently if the var is not instantiated in solution Java raise an exception Need to be added a new function in backend to check if the var is instantiated