Solver

Struct Solver 

pub struct Solver<'model> { /* private fields */ }
A solver instance associated with a Model.

Provides solution search and propagation utilities for the model.

Implementations

Source

impl<'model> Solver<'model>

pub fn set_time_limit(&self, time_limit_ms: i64)

Sets the time limit for the solver in milliseconds.

Panics

Panics if time_limit_ms is negative.

pub fn find_solution(&self, criterions: &Criterion) -> Option<Solution>

pub fn propagate(&self) -> Result<(), SolverError>

Propagates constraints and related events through the constraint network until a fix point is find, or a contradiction is detected.

Returns

SolverError::FoundContradiction if a contradiction is detected during propagation.