pub enum ESat {
True,
False,
Undefined,
}Expand description
Represents the satisfaction state of a constraint.
This enum indicates whether a constraint is satisfied, not satisfied, or if it is not yet possible to determine its satisfaction state.
Variants
True
The constraint is satisfied.
False
The constraint is not satisfied.
Undefined
The satisfaction state cannot be determined yet.